@@ -123,7 +123,7 @@ impl std::io::Seek for PhysFsHandle {
         match pos {
             SeekFrom::Start(pos) => unsafe {
                 let ret = physfs_sys::PHYSFS_seek(self.handle, pos);
-                if ret != 0 {
+                if ret == 0 {
                     Err(std::io::Error::new(
                         std::io::ErrorKind::Other,
                         get_last_error().err().unwrap(),
@@ -137,7 +137,7 @@ impl std::io::Seek for PhysFsHandle {
                 self.seek(SeekFrom::Start((cpos + pos) as u64))
             },
             SeekFrom::End(pos) => unsafe {
-                let cpos = physfs_sys::PHYSFS_fileLength(self.handle) - 1;
+                let cpos = physfs_sys::PHYSFS_fileLength(self.handle);
                 self.seek(SeekFrom::Start((cpos + pos) as u64))
             },
         }
